@@ -22,8 +22,8 @@ def random(N=64):
 
 def get_commands():
     commands = [
-        #"{owncloud_path}occ market:install oauth2",
-        #"{owncloud_path}occ market:install rds",
+        # "{owncloud_path}occ market:install oauth2",
+        # "{owncloud_path}occ market:install rds",
         "{owncloud_path}occ app:enable oauth2",
         "{owncloud_path}occ app:enable rds",
         "{owncloud_path}occ oauth2:add-client {oauthname} {client_id} {client_secret} {rds_domain}",
@@ -162,20 +162,30 @@ def init(self_signed, overwrite_values, single_file):
                 err=True,
             )
 
+    cnt = requests.get(
+        "https://raw.githubusercontent.com/Sciebo-RDS/Sciebo-RDS/release/getting-started/values.yaml.example"
+    ).text
+
+    cfg = requests.get(
+        "https://raw.githubusercontent.com/Sciebo-RDS/Sciebo-RDS-CLI/develop/config.yaml.example"
+    ).text
+
+    if (not os.path.isfile(config_file_path) or overwrite_values) and not single_file:
+        if overwrite_values:
+            click.echo(f"WARN: Overwrites {config_file_path} if it exists.")
+
+        with open(config_file_path, "w") as f:
+            f.write(cfg)
+            click.echo(f"{config_file_path} created.")
+
     if not os.path.isfile(values_file_path) or overwrite_values:
         if overwrite_values:
             click.echo(f"WARN: Overwrites {values_file_path} if it exists.")
 
-        cnt = requests.get(
-            "https://raw.githubusercontent.com/Sciebo-RDS/Sciebo-RDS/release/getting-started/values.yaml.example"
-        ).text
         if single_file:
             click.echo(
                 f"WARN: Places {config_file_path} content at the top of {values_file_path}."
             )
-            cfg = requests.get(
-                "https://raw.githubusercontent.com/Sciebo-RDS/Sciebo-RDS-CLI/develop/config.yaml.example"
-            ).text
             cnt = cfg + "\n\n\n" + cnt
 
         with open(values_file_path, "w") as f:
@@ -187,9 +197,14 @@ def init(self_signed, overwrite_values, single_file):
             err=True,
         )
 
-    click.echo(
-        f"Adjust the {values_file_path} to your needs with your favourite editor, before you `install` sciebo RDS."
-    )
+    if not single_file:
+        click.echo(
+            f"Adjust the {values_file_path} and {config_file_path} to your needs with your favourite editor, before you `install` sciebo RDS."
+        )
+    else:
+        click.echo(
+            f"Adjust the {values_file_path} to your needs with your favourite editor, before you `install` sciebo RDS."
+        )
 
 
 @click.command()
@@ -246,7 +261,7 @@ def checks(single_file):
     "dry_run",
     is_flag=True,
     default=False,
-    help="Execute install without any changes. WARNING: It connects to the ownCloud instances and your k8s cluster via SSH and Kubectl nevertheless, but it does not change anything.",
+    help="Execute install without any changes. WARNING: It connects to the ownCloud instances and your k8s cluster via SSH and Kubectl to get some informations. Nevertheless it does not change anything.",
 )
 @click.argument(
     "values_file",
@@ -316,7 +331,7 @@ ownCloud needs php-gmp for oauth2 plugin. Install it on your own.
     type=click.Path(exists=True),
     is_flag=False,
     flag_value=Path(f"{os.getcwd()}/config.yaml"),
-    help="The given path will be used as config.yaml file. If not given, it will use the values.yaml per default otherwise.",
+    help="The given path will be used as config.yaml file. If not given, it will use the values.yaml per default as a single-file-configuration otherwise.",
 )
 @click.argument(
     "values_file",
@@ -328,7 +343,7 @@ ownCloud needs php-gmp for oauth2 plugin. Install it on your own.
     "dry_run",
     is_flag=True,
     default=False,
-    help="Execute install without any changes. WARNING: It connects to the ownCloud instances and your k8s cluster via SSH and Kubectl nevertheless, but it does not change anything.",
+   help="Execute install without any changes. WARNING: It connects to the ownCloud instances and your k8s cluster via SSH and Kubectl to get some informations. Nevertheless it does not change anything.",
 )
 def install(force_kubectl, helm_install, values_file, file, dry_run):
     """
@@ -425,6 +440,9 @@ def install(force_kubectl, helm_install, values_file, file, dry_run):
             )
 
             if dry_run:
+                click.echo(
+                    "SSH can connect to ownCloud server: {}".format(val["address"])
+                )
                 continue
 
             owncloud_url = execute(
@@ -485,6 +503,11 @@ def install(force_kubectl, helm_install, values_file, file, dry_run):
             )
 
             if dry_run:
+                click.echo(
+                    "kubectl can connect to ownCloud label: {}, container: {}".format(
+                        selector, containername
+                    )
+                )
                 continue
 
             owncloud_url = execute(
